@@ -24,12 +24,12 @@ def to_bytes(value):
     """ str to bytes (py3k) """
     vtype = type(value)
 
-    if vtype == bytes:
+    if vtype == bytes or vtype == type(None):
         return value
 
     try:
         return vtype.encode(value)
-    except UnicodeDecodeError:
+    except UnicodeEncodeError:
         pass
     return value
 
